ConnectionService

Struct ConnectionService 

pub struct ConnectionService { /* private fields */ }
Implements a client for the BigQuery Connection API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = ConnectionService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_connections()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Manages external data source connections and credentials.

Configuration

To configure ConnectionService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://bigqueryconnection.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

ConnectionService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap ConnectionService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl ConnectionService

pub fn builder() -> ClientBuilder

Returns a builder for ConnectionService.

let client = ConnectionService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: ConnectionService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_connection(&self) -> CreateConnection

Creates a new connection.

Example
use google_cloud_bigquery_connection_v1::model::Connection;
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService, parent: &str
) -> Result<()> {
    let response = client.create_connection()
        .set_parent(parent)
        .set_connection_id("connection_id_value")
        .set_connection(
            Connection::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_connection(&self) -> GetConnection

Returns specified connection.

Example
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService, name: &str
) -> Result<()> {
    let response = client.get_connection()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_connections(&self) -> ListConnections

Returns a list of connections in the given project.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService, parent: &str
) -> Result<()> {
    let mut list = client.list_connections()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_connection(&self) -> UpdateConnection

Updates the specified connection. For security reasons, also resets credential if connection properties are in the update field mask.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_bigquery_connection_v1::model::Connection;
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService, name: &str
) -> Result<()> {
    let response = client.update_connection()
        .set_connection(
            Connection::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_connection(&self) -> DeleteConnection

Deletes connection and associated credential.

Example
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService, name: &str
) -> Result<()> {
    client.delete_connection()
        .set_name(name)
        .send().await?;
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_bigquery_connection_v1::Result;
async fn sample(
   client: &ConnectionService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}